#!/usr/bin/env python
"""
The one Squirro CLI tool to rule them all :-)
"""
import logging
import os
import sys

from cluster import add_cluster_args
from elastic import add_es_args
from project import add_project_args
from utils import get_arg_parser, setup_logging

from squirro_client import SquirroClient

# Script version. It's recommended to increment this with every change, to make
# debugging easier.
VERSION = '2.6.0'

logging.getLogger("urllib3").setLevel(logging.WARNING)
logging.getLogger("urllib3.util.retry").setLevel(logging.WARNING)

# Set up logging.
log = logging.getLogger('{0}[{1}]'.format(os.path.basename(sys.argv[0]),
                                          os.getpid()))

def main():
    """Main Function"""
    parser = get_arg_parser()

    subparsers = parser.add_subparsers(help='sub-command help')
    add_cluster_args(subparsers)
    add_es_args(subparsers)
    add_project_args(subparsers)
    args = parser.parse_args()

    if args.cluster and args.token:
        #get a squirro client
        squirro_client = SquirroClient(None, None, cluster=args.cluster)
        squirro_client.authenticate(refresh_token=args.token)
        args.squirro_client = squirro_client

    setup_logging(args)
    args.func(**vars(args))

if __name__ == "__main__":
    main()
